@@ -14,11 +14,13 @@
 #include <QVBoxLayout>
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
+
+#ifdef USE_KUSERFEEDBACK_QT6
+#include <KUserFeedbackQt6/FeedbackConfigWidget>
+#else
 #include <KUserFeedback/FeedbackConfigWidget>
 #endif
 
-#ifdef WITH_KUSERFEEDBACK
-
 K_PLUGIN_CLASS_WITH_JSON(KOPrefsUserFeedBack, "korganizer_userfeedback.json")
 
 KOPrefsUserFeedBack::KOPrefsUserFeedBack(QWidget *parent, const QVariantList &args)
